/**
 * Created by jmoutard on 21/07/16.
 */

'use strict';

angular.module('adf.electre')
    .controller('navigationCtrl', [
        "$scope", "$rootScope", "$q", "$state", "$location", "storeService", "defaultDashboard", "$timeout", "loggedIn",
        function ($scope, $rootScope, $q, $state, $location, storeService, defaultDashboard, $timeout, loggedIn) {
            /**
             * @description Display errors from the storage service.
             * @param {object} error Error from the storage service.
             */
            function displayError (error) {
                $scope.errorMessage = (error.message ? error.message() : error);
                $timeout(function () {
                    $scope.errorMessage = false;
                }, 2500);
            }
            /**
             * @description Taking the dashboards from the storage. Creating objects for the navbar menu.
             * @param {Array} values Data given by the storage.
             */
            function takeDashboards (values) {
                if (values && typeof values === "object") {
                    nav.items = values;
                }
            }
            /**
             * @description Removing all dashboard's object in order to clear the navbar menu.
             */
            function resetDashboards () {
                nav.items = [];
            }

            $scope.message = { 
                hasMessage: false,
                onRemote : loggedIn
            };

            var nav = this;
            nav.navCollapsed = false;
            nav.username = window.lavoisier_user;
            nav.items = [];

            this.toggleNav = function(){ nav.navCollapsed = !nav.navCollapsed; };

            this.navClass = function(id) { return id === $state.params.id ? 'active' : ''; };

            /**
             * @description Change the state to 'board.create' which will create a new dashboard, save it and fire an event called 'dashboardCreated'.
             */
            this.create = function(){ $state.go("board.create", { id : '_' + Date.now() }); };
            this.moveTo = function (element) { $state.go("board." + element.item.state, { id : element.item.id }); };
            this.delete = function (element) { $state.go('board.remove', { id:element.item.id }); };

            storeService.getAll().then(takeDashboards);
            
            $scope.$on('navChanged', function(){
                resetDashboards();
                storeService.getAll().then(takeDashboards);
            });

            /*$scope.$on('removeDashboard', function (event, id) { $state.go('board.remove', { id:id }); });*/
            $scope.$on('createAndImportDashboard', function (event, dashboardString) { $state.go('board.import', { dashboard:dashboardString }); });
            $scope.$on('duplicateDashboard', function (event, dashboard) { $state.go('board.duplicate', { dashboard:JSON.stringify(dashboard) }); });
            $scope.$on('dashboardCopied', function () {
                $scope.$apply(function () {
                    $scope.message.hasMessage = true;
                    $scope.message.exported = true;
                });
                $timeout(function() {
                    $scope.$apply(function () {
                        $scope.message.hasMessage = false;
                        $scope.message.exported = false;
                    });
                }, 3000);
            });
            $scope.$on('dashboardCreated', function (event, id) {
                $scope.$emit('navChanged');
                $state.go("board." + (loggedIn ? "remote" : "local"), {id:id});
            });
            $scope.$on('dashboardRemoved', function () {
                $scope.$emit('navChanged');
                $state.go("home");
            });

            $scope.$on("creatingError", function () {
                $scope.message.hasMessage = true;
                $scope.message.error = true;
                $scope.message.while = { create : true };
            });
            $scope.$on("deletingError", function () {
                $scope.message.hasMessage = true;
                $scope.message.error = true;
                $scope.message.while = { delete : true };
            });

            /* ROUTING */
            $rootScope.$on('$stateChangeStart', function (event, toState, toParams, fromState, fromParams) {
                var isDashboardNotSaved = {answer:true};
                $rootScope.$broadcast("isDashboardSaved", isDashboardNotSaved);
                if (!isDashboardNotSaved.answer)
                if (fromState.name === "local_board" || fromState.name === "remote_board")
                if (!confirm("Dashboard not saved ! Are you sure you want to leave without saving the dashboard ?"))
                    event.preventDefault();
            });
            $rootScope.$on('$stateChangeError', function (event, toState, toParams, fromState, fromParams, error) {
                $scope.message.hasMessage = true;
                $scope.message.error = true;
                $scope.message.connectionLost = true;
            });
            $rootScope.$on('$stateChangeSuccess', function (event, toState, toParams, fromState, fromParams) {
                if ($scope.message.hasMessage) {
                    $scope.message.hasMessage = false;
                    $scope.message.connectionLost = false;
                    $scope.message.exported = false;
                    $scope.message.error = false;
                    $scope.message.while = undefined;
                }
                if (toState.name === 'logout') {
                    $rootScope.$broadcast('navChanged');
                    $location.path('/');
                }
            });
        }
    ]);