<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:t="http://software.in2p3.fr/lavoisier/tables.xsd"
                xmlns="http://www.w3.org/1999/xhtml">
    <xsl:include href="/resource/xsl/head.xsl"/>
    <xsl:include href="/resource/xsl/navbar.xsl"/>
    <xsl:output method="html"/>

    <xsl:template match="/t:tables">
        <html>
            <head>
                <title><xsl:value-of select="@title"/></title>
                <style type="text/css">
                    h2             {text-align: center;}
                    TD             {text-align: left;}
                    TD.number      {text-align: right;}
                </style>
                <xsl:call-template name="head"/>
            </head>
            <body>
                <xsl:call-template name="navbar"/>
                <div class="container">
                    <h2 class="page-title text-center"><xsl:value-of select="@title"/></h2>
                    <xsl:for-each select="t:fields">
                        <ul>
                            <xsl:for-each select="t:field">
                                <li>
                                    <b><xsl:value-of select="@label"/>: </b><xsl:value-of select="text()"/>
                                </li>
                            </xsl:for-each>
                        </ul>
                    </xsl:for-each>
                    <xsl:for-each select="t:table">
                        <div style="margin-top:50px">
                            <xsl:for-each select="self::t:table[preceding-sibling::t:table | following-sibling::t:table]/@name">
                                <h4><xsl:value-of select="."/></h4>
                            </xsl:for-each>
                            <table class="table table-bordered table-striped table-sorted table-hover">
                                <thead>
                                    <xsl:for-each select="t:column_labels">
                                        <tr>
                                            <xsl:for-each select="t:column_label">
                                                <th>
                                                    <xsl:value-of select="text()"/>
                                                    <xsl:if test="@unit"> (<xsl:value-of select="@unit"/>)</xsl:if>
                                                </th>
                                            </xsl:for-each>
                                        </tr>
                                    </xsl:for-each>
                                </thead>
                                <tbody>
                                    <xsl:for-each select="t:row">
                                        <tr>
                                            <xsl:for-each select="t:column">
                                                <td>
                                                    <xsl:choose>
                                                        <xsl:when test="@link">
                                                            <a href="{@link}">
                                                                <xsl:value-of select="text()"/>
                                                            </a>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <xsl:value-of select="text()"/>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                            </xsl:for-each>
                                        </tr>
                                    </xsl:for-each>
                                </tbody>
                            </table>
                        </div>
                    </xsl:for-each>
                </div>
            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>